<?php

namespace Database\Seeders;

use App\Models\Flat;
use App\Models\Invoice;
use App\Models\MaintainceTemplate;
use App\Models\Owner;
use App\Models\Society;
use App\Models\User;
use App\Models\Wing;
use Illuminate\Database\Seeder;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void {
        // create admin
        User::factory()->admin()->create();

        // create a society and its maintenance template
        $society = Society::factory()->create();
        $maintainanceTemplate = MaintainceTemplate::factory()->create([
            "society_id" => $society->id,
        ]);

        $wingNames = ["A", "B", "C", "D"];

        foreach ($wingNames as $wing_name) {
            $wing = Wing::factory()->create([
                "society_id" => $society->id,
                "wing_name" => $wing_name,
            ]);

            for ($i = 1; $i <= fake()->numberBetween(1, (int) $wing->no_flats); $i++) {
                $owner = Owner::factory()->create([
                    "society_id" => $society->id,
                ]);

                $flat = Flat::factory()->create([
                    "society_id" => $society->id,
                    "wing_id" => $wing->id,
                    "owner_id" => $owner->id,
                    "flat_no" => "10".$i,
                    "status" => "active",
                ]);

                $user = User::factory()->create([
                    "owner_id" => $owner->id,
                    "flat_id" => $flat->id,
                    "name" => $owner->name,
                    "email" => $owner->email,
                    "phone" => $owner->phone,
                    "role" => "owner"
                ]);
            }
        }

        $flats = Flat::query()->where("society_id", $maintainanceTemplate->society_id)
            ->where("status", "active")->get();

        foreach ($flats as $flat) {
            Invoice::factory()->create([
                "society_id" => $flat->society_id,
                "flat_id" => $flat->id,

                'maintainance_cost' => $flat->flat_sqrft * $maintainanceTemplate->per_sqrft_maintaince_cost,
                'property_tax_cost' => $flat->flat_sqrft * $maintainanceTemplate->per_sqrft_property_tax,
                'water_charges' => $maintainanceTemplate->water_charges / $flats->count(),
                'bill_month' => now()->format('M'),
                'bill_date' => now()->format('d-m-y'),
                'bill_year' => now()->format('Y'),
            ]);
        }
    }
}
